@@ -305,7 +305,9 @@ librdf_storage_trees_remove_statement_internal(librdf_storage_trees_graph* graph
   if (graph->pso_tree)
     librdf_avltree_delete(graph->pso_tree, statement);
   
-  return librdf_avltree_delete(graph->spo_tree, statement);
+  librdf_avltree_delete(graph->spo_tree, statement);
+  
+  return 0;
 }
 
 
@@ -632,7 +634,21 @@ librdf_storage_trees_node_compare(librdf_node* n1, librdf_node* n2)
       case LIBRDF_NODE_TYPE_RESOURCE:
         return librdf_uri_compare(n1->value.resource.uri, n2->value.resource.uri);
       case LIBRDF_NODE_TYPE_LITERAL:
-        return strcmp((char*)n1->value.literal.string, (char*)n2->value.literal.string);
+        if(1) {
+          int r;
+          r = librdf_uri_compare(n1->value.literal.datatype_uri,
+                                 n2->value.literal.datatype_uri);
+          if(!r) {
+            unsigned char l1 = n1->value.literal.xml_language_len;
+            unsigned char l2 = n2->value.literal.xml_language_len;
+            unsigned l = (l1 < l2) ? l1 : l2;
+            r = strncmp(n1->value.literal.xml_language,
+                        n2->value.literal.xml_language, l);
+          }
+          r = r || strcmp((const char*)n1->value.literal.string,
+                          (const char*)n2->value.literal.string);
+          return r;
+        }
       case LIBRDF_NODE_TYPE_BLANK:
         return strcmp((char*)n1->value.blank.identifier, (char*)n2->value.blank.identifier);
       case LIBRDF_NODE_TYPE_UNKNOWN:
